@@ -41,7 +41,7 @@ async def _read_stdout(stdout):
                 decoded_bytes = base64.b64decode(response)
                 response = json.loads(str(decoded_bytes, "utf-8"))
                 await response_function(response.get("Message", "Response does not contain Message."), response)
-            elif "Caching task done." in response:
+            elif b"Caching task done." in response:
                 await response_function("Caching task done.", {})
             else:
                 print('stdout: ' + response.decode('utf-8'))
